@@ -1,4 +1,4 @@
-from arpakitlib.ar_sqlalchemy_util import get_string_info_from_declarative_base, get_string_info_from_declarative_base_2
+from arpakitlib.ar_sqlalchemy_util import get_string_info_from_declarative_base_2
 
 from project.sqlalchemy_db_.sqlalchemy_model.api_key import ApiKeyDBM
 from project.sqlalchemy_db_.sqlalchemy_model.common import SimpleDBM
